@@ -10,7 +10,7 @@ from __future__ import annotations
 import abc
 from abc import abstractmethod
 from statistics import mean
-from typing import Dict, List
+from typing import Dict, List, Optional
 
 import pynguin.ga.fitnessfunction as ff
 
@@ -18,12 +18,20 @@ import pynguin.ga.fitnessfunction as ff
 class Chromosome(metaclass=abc.ABCMeta):
     """An abstract base class for chromosomes"""
 
-    def __init__(self):
+    def __init__(self, orig: Optional[Chromosome] = None):
+        """
+        Args:
+            orig: Original, if we clone an existing chromosome.
+        """
         self._fitness_functions: List[ff.FitnessFunction] = []
-        self._current_values: Dict[ff.FitnessFunction, ff.FitnessValues] = dict()
-
+        self._current_values: Dict[ff.FitnessFunction, ff.FitnessValues] = {}
         self._number_of_evaluations: int = 0
         self._changed: bool = True
+        if orig is not None:
+            self._fitness_functions = list(orig._fitness_functions)
+            self._current_values = dict(orig._current_values)
+            self._number_of_evaluations = orig._number_of_evaluations
+            self._changed = orig._changed
 
     @abstractmethod
     def size(self) -> int:
@@ -91,7 +99,10 @@ class Chromosome(metaclass=abc.ABCMeta):
             raise RuntimeError(", ".join(violations))
         self._current_values[fitness_function] = new_value
 
-    def add_fitness_function(self, fitness_function: ff.FitnessFunction,) -> None:
+    def add_fitness_function(
+        self,
+        fitness_function: ff.FitnessFunction,
+    ) -> None:
         """Adds a fitness function.
 
         Args:
