@@ -14,8 +14,7 @@ from pynguin.testcase.execution.executionresult import ExecutionResult
 
 # pylint: disable=abstract-method
 class AbstractSuiteFitnessFunction(ff.FitnessFunction, metaclass=ABCMeta):
-    """Abstract fitness function for test suites.
-    """
+    """Abstract fitness function for test suites."""
 
     def _run_test_suite(self, individual) -> List[ExecutionResult]:
         """Runs a test suite and updates the execution results for
@@ -30,7 +29,7 @@ class AbstractSuiteFitnessFunction(ff.FitnessFunction, metaclass=ABCMeta):
         results: List[ExecutionResult] = []
         for test_case in individual.test_chromosomes:
             if test_case.has_changed() or test_case.get_last_execution_result() is None:
-                test_case.set_last_execution_result(self._executor.execute([test_case]))
+                test_case.set_last_execution_result(self._executor.execute(test_case))
                 test_case.set_changed(False)
             result = test_case.get_last_execution_result()
             assert result
