@@ -57,7 +57,9 @@ class RandomTestStrategy(TestGenerationStrategy):
                 generation += 1
                 stopping_condition.iterate()
                 self.generate_sequence(
-                    test_chromosome, failing_test_chromosome, generation,
+                    test_chromosome,
+                    failing_test_chromosome,
+                    generation,
                 )
                 combined_chromosome = self._combine_current_individual(
                     test_chromosome, failing_test_chromosome
@@ -133,7 +135,7 @@ class RandomTestStrategy(TestGenerationStrategy):
 
         with Timer(name="Execution time", logger=None):
             # Execute new sequence
-            exec_result = self._executor.execute([new_test])
+            exec_result = self._executor.execute(new_test)
 
         # Classify new test case and outputs
         if exec_result.has_test_exceptions():
@@ -153,7 +155,7 @@ class RandomTestStrategy(TestGenerationStrategy):
         combined.add_tests(failing_chromosome.test_chromosomes)
         return combined
 
-    def send_statistics(self):
+    def send_statistics(self) -> None:
         super().send_statistics()
         tracker = StatisticsTracker()
         tracker.track_output_variable(
