@@ -17,15 +17,18 @@ Pynguin is supposed to be used as a standalone command-line application but it
 can also be used as a library by instantiating this class directly.
 """
 import enum
+import importlib
 import logging
 import os
 import sys
 import time
 from typing import Callable, Dict, List, Optional, Tuple
 
+import pynguin.assertion.assertiongenerator as ag
 import pynguin.configuration as config
 import pynguin.testcase.testcase as tc
 import pynguin.testsuite.testsuitechromosome as tsc
+from pynguin.analyses.duckmock.duckmockanalysis import DuckMockAnalysis
 from pynguin.analyses.seeding.staticconstantseeding import StaticConstantSeeding
 from pynguin.generation.algorithms.randoopy.randomteststrategy import RandomTestStrategy
 from pynguin.generation.algorithms.testgenerationstrategy import TestGenerationStrategy
@@ -75,21 +78,11 @@ class Pynguin:
     _logger = logging.getLogger(__name__)
 
     def __init__(self, configuration: config.Configuration) -> None:
-        """Initialises the test generator.
-
-        The generator needs a configuration. If none is present, the generator
-        cannot be initialised and will thus raise a `ConfigurationException`.
+        """Initialises the test generator with the given configuration.
 
         Args:
-            configuration: An optional pre-generated configuration.
-
-        Raises:
-            ConfigurationException: In case there is no proper configuration
+            configuration: The configuration to use.
         """
-        if configuration is None:
-            raise ConfigurationException(
-                "Cannot initialise test generator without proper configuration."
-            )
         config.INSTANCE = configuration
 
     def run(self) -> ReturnCode:
@@ -109,16 +102,6 @@ class Pynguin:
         finally:
             self._logger.info("Stop Pynguin Test Generation…")
 
-    def _setup_executor(self, tracer: ExecutionTracer) -> Optional[TestCaseExecutor]:
-        try:
-            executor = TestCaseExecutor(tracer)
-        except ImportError as ex:
-            # A module could not be imported because some dependencies
-            # are missing or it is malformed
-            self._logger.error("Failed to load SUT: %s", ex)
-            return None
-        return executor
-
     def _setup_test_cluster(self) -> Optional[TestCluster]:
         with Timer(name="Test-cluster generation time", logger=None):
             test_cluster = TestClusterGenerator(
@@ -129,21 +112,23 @@ class Pynguin:
                 return None
             return test_cluster
 
-    def _setup_path_and_hook(self) -> Optional[ExecutionTracer]:
-        """Inserts the path to the SUT into the path list.
-
-        Also installs the import hook.
+    def _setup_path(self) -> bool:
+        """Inserts the path to the SUT into the path list, installs the import hook and
+        tries to load the SUT.
 
         Returns:
-            An optional execution tracer
+            An optional execution tracer, if loading was successful, None otherwise.
         """
         if not os.path.isdir(config.INSTANCE.project_path):
             self._logger.error(
                 "%s is not a valid project path", config.INSTANCE.project_path
             )
-            return None
+            return False
         self._logger.debug("Setting up path for %s", config.INSTANCE.project_path)
         sys.path.insert(0, config.INSTANCE.project_path)
+        return True
+
+    def _setup_import_hook(self) -> ExecutionTracer:
         self._logger.debug(
             "Setting up instrumentation for %s", config.INSTANCE.module_name
         )
@@ -151,6 +136,16 @@ class Pynguin:
         install_import_hook(config.INSTANCE.module_name, tracer)
         return tracer
 
+    def _load_sut(self) -> bool:
+        try:
+            importlib.import_module(config.INSTANCE.module_name)
+        except ImportError as ex:
+            # A module could not be imported because some dependencies
+            # are missing or it is malformed
+            self._logger.error("Failed to load SUT: %s", ex)
+            return False
+        return True
+
     def _setup_random_number_generator(self) -> None:
         """Setup RNG."""
         if config.INSTANCE.seed is None:
@@ -165,6 +160,17 @@ class Pynguin:
             self._logger.info("Collecting constants from SUT.")
             StaticConstantSeeding().collect_constants(config.INSTANCE.project_path)
 
+    def _setup_type_analysis(
+        self, test_cluster: TestCluster
+    ) -> Optional[DuckMockAnalysis]:
+        if config.INSTANCE.duck_type_analysis:
+            self._logger.info("Analysing classes and methods in SUT.")
+            analysis = DuckMockAnalysis(config.INSTANCE.module_name)
+            analysis.analyse()
+            analysis.update_test_cluster(test_cluster)
+            return analysis
+        return None
+
     def _setup_and_check(self) -> Optional[Tuple[TestCaseExecutor, TestCluster]]:
         """Load the System Under Test (SUT) i.e. the module that is tested.
 
@@ -173,15 +179,20 @@ class Pynguin:
         Returns:
             An optional tuple of test-case executor and test cluster
         """
-        if (tracer := self._setup_path_and_hook()) is None:
+
+        if not self._setup_path():
             return None
-        if (executor := self._setup_executor(tracer)) is None:
+        tracer = self._setup_import_hook()
+        if not self._load_sut():
             return None
         if (test_cluster := self._setup_test_cluster()) is None:
             return None
+        executor = TestCaseExecutor(tracer)
         self._track_sut_data(tracer, test_cluster)
         self._setup_random_number_generator()
         self._setup_constant_seeding_collection()
+        if (type_analysis := self._setup_type_analysis(test_cluster)) is not None:
+            self._export_type_analysis_results(type_analysis)
         return executor, test_cluster
 
     @staticmethod
@@ -215,8 +226,8 @@ class Pynguin:
         executor, test_cluster = setup_result
 
         with Timer(name="Test generation time", logger=None):
-            algorithm: TestGenerationStrategy = self._instantiate_test_generation_strategy(
-                executor, test_cluster
+            algorithm: TestGenerationStrategy = (
+                self._instantiate_test_generation_strategy(executor, test_cluster)
             )
             self._logger.info(
                 "Start generating sequences using %s", config.INSTANCE.algorithm
@@ -238,6 +249,12 @@ class Pynguin:
                     RuntimeVariable.Coverage, combined.get_coverage()
                 )
 
+            if config.INSTANCE.generate_assertions:
+                generator = ag.AssertionGenerator(executor)
+                for chromosome in [non_failing, failing]:
+                    generator.add_assertions(chromosome.test_chromosomes)
+                    generator.filter_failing_assertions(chromosome.test_chromosomes)
+
             with Timer(name="Export time", logger=None):
                 written_to = self._export_test_cases(non_failing.test_chromosomes)
                 self._logger.info(
@@ -256,7 +273,7 @@ class Pynguin:
         self._collect_statistics()
         if not StatisticsTracker().write_statistics():
             self._logger.error("Failed to write statistics data")
-        if combined.size == 0:
+        if combined.size() == 0:
             # not able to generate one test case
             return ReturnCode.NO_TESTS_GENERATED
         return ReturnCode.OK
@@ -308,7 +325,8 @@ class Pynguin:
         )
         tracker.track_output_variable(RuntimeVariable.FailingSize, failing.size())
         tracker.track_output_variable(
-            RuntimeVariable.FailingLength, failing.total_length_of_test_cases,
+            RuntimeVariable.FailingLength,
+            failing.total_length_of_test_cases,
         )
         tracker.track_output_variable(RuntimeVariable.PassingSize, non_failing.size())
         tracker.track_output_variable(
@@ -337,3 +355,7 @@ class Pynguin:
         )
         exporter.export_sequences(target_file, test_cases)
         return target_file
+
+    @staticmethod
+    def _export_type_analysis_results(type_analysis: DuckMockAnalysis):
+        pass
