@@ -221,7 +221,8 @@ class ParametrizedStatement(stmt.Statement, metaclass=ABCMeta):  # pylint: disab
             # The chosen replacement is a copy, so we have to add it to the test case.
             self.test_case.add_statement(copy, self.get_position())
         elif replacement is none_statement.return_value:
-            # The chosen replacement is a none statement, so we have to add it to the test case.
+            # The chosen replacement is a none statement, so we have to add it to the
+            # test case.
             self.test_case.add_statement(none_statement, self.get_position())
 
         self._replace_argument(arg, replacement)
@@ -313,11 +314,14 @@ class ConstructorStatement(ParametrizedStatement):
     def __repr__(self) -> str:
         return (
             f"ConstructorStatement({self._test_case}, "
-            f"{self._generic_callable}(args={self._args}, kwargs={self._kwargs})"
+            + f"{self._generic_callable}(args={self._args}, kwargs={self._kwargs})"
         )
 
     def __str__(self) -> str:
-        return f"{self._generic_callable}(args={self._args}, kwargs={self._kwargs}) -> None"
+        return (
+            f"{self._generic_callable}(args={self._args}, kwargs={self._kwargs}) "
+            + "-> None"
+        )
 
 
 class MethodStatement(ParametrizedStatement):
@@ -342,7 +346,10 @@ class MethodStatement(ParametrizedStatement):
             kwargs: the keyword arguments
         """
         super().__init__(
-            test_case, generic_callable, args, kwargs,
+            test_case,
+            generic_callable,
+            args,
+            kwargs,
         )
         self._callee = callee
 
@@ -415,14 +422,14 @@ class MethodStatement(ParametrizedStatement):
     def __repr__(self) -> str:
         return (
             f"MethodStatement({self._test_case}, "
-            f"{self._generic_callable}, {self._callee.variable_type}, "
-            f"args={self._args}, kwargs={self._kwargs})"
+            + f"{self._generic_callable}, {self._callee.variable_type}, "
+            + f"args={self._args}, kwargs={self._kwargs})"
         )
 
     def __str__(self) -> str:
         return (
             f"{self._generic_callable}(args={self._args}, kwargs={self._kwargs}) -> "
-            f"{self._generic_callable.generated_type()}"
+            + f"{self._generic_callable.generated_type()}"
         )
 
 
@@ -451,12 +458,12 @@ class FunctionStatement(ParametrizedStatement):
     def __repr__(self) -> str:
         return (
             f"FunctionStatement({self._test_case}, "
-            f"{self._generic_callable}, {self._return_value.variable_type}, "
-            f"args={self._args}, kwargs={self._kwargs})"
+            + f"{self._generic_callable}, {self._return_value.variable_type}, "
+            + f"args={self._args}, kwargs={self._kwargs})"
         )
 
     def __str__(self) -> str:
         return (
             f"{self._generic_callable}(args={self._args}, kwargs={self._kwargs}) -> "
-            f"{self._return_value.variable_type}"
+            + f"{self._return_value.variable_type}"
         )
