@@ -8,8 +8,9 @@
 from __future__ import annotations
 
 from abc import ABCMeta, abstractmethod
-from typing import List, Optional, Type
+from typing import List, Optional, Set, Type
 
+import pynguin.assertion.assertion as ass
 import pynguin.testcase.statements.statement as stmt
 import pynguin.testcase.testcasevisitor as tcv
 import pynguin.testcase.variable.variablereference as vr
@@ -155,18 +156,6 @@ class TestCase(metaclass=ABCMeta):
             A deep copy of this test case  # noqa: DAR202
         """
 
-    @abstractmethod
-    def is_failing(self) -> bool:
-        """Checks if the test case is a failing test or not
-
-        Returns:
-            Whether or not the test case is failing  # noqa: DAR202
-        """
-
-    @abstractmethod
-    def set_failing(self) -> None:
-        """Marks the test case as a failing test."""
-
     @abstractmethod
     def size(self) -> int:
         """Provides the number of statements in the test case.
@@ -175,6 +164,29 @@ class TestCase(metaclass=ABCMeta):
             The number of statements in the test case  # noqa: DAR202
         """
 
+    @abstractmethod
+    def size_with_assertions(self) -> int:
+        """Provides the number of statements and assertions in the test case.
+
+        Returns:
+            The number of statements and assertions in the test case # noqa: DAR202
+        """
+
+    @abstractmethod
+    def get_assertions(self) -> List[ass.Assertion]:
+        """Get all assertions that exist for this test case."""
+
+    @abstractmethod
+    def get_dependencies(self, var: vr.VariableReference) -> Set[vr.VariableReference]:
+        """Provides all variables on which var depends.
+
+        Args:
+            var: the variable whose dependencies we are looking for.
+
+        Returns:
+            a set of variables on which var depends on. # noqa: DAR202
+        """
+
     def get_objects(
         self, parameter_type: Optional[Type], position: int
     ) -> List[vr.VariableReference]:
